﻿using System;
using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "NavigationView 엘리먼트 : 계층 메뉴 사용하기";

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 네비게이션 뷰 선택 변경시 처리하기 - navigationView_SelectionChanged(sender, e)

        /// <summary>
        /// 네비게이션 뷰 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void navigationView_SelectionChanged(Microsoft.UI.Xaml.Controls.NavigationView sender, Microsoft.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs e)
        {
            if(e.IsSettingsSelected)
            {
                this.frame.Navigate(typeof(SampleSettingPage));
            }
            else
            {
                Microsoft.UI.Xaml.Controls.NavigationViewItem item = e.SelectedItem as Microsoft.UI.Xaml.Controls.NavigationViewItem;

                string itemTag = item.Tag.ToString();

                sender.Header = "샘플 페이지 " + itemTag.Substring(itemTag.Length - 1);

                string pageName = "TestProject." + itemTag;

                Type pageType = Type.GetType(pageName);

                this.frame.Navigate(pageType);
            }
        }

        #endregion
        #region 왼쪽 창 위치 라디오 버튼 체크시 처리하기 - leftPanePositionRadioButton_Checked(sender, e)

        /// <summary>
        /// 왼쪽 창 위치 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void leftPanePositionRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            this.navigationView.PaneDisplayMode = Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode.Left;
            this.navigationView.IsPaneOpen      = true;
        }

        #endregion
        #region 위쪽 창 위치 라디오 버튼 체크시 처리하기 - topPanePositionRadioButton_Checked(sender, e)

        /// <summary>
        /// 위쪽 창 위치 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void topPanePositionRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            this.navigationView.PaneDisplayMode = Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode.Top;
            this.navigationView.IsPaneOpen      = false;
        }

        #endregion
        #region 왼쪽 컴팩트 창 위치 라디오 버튼 체크시 처리하기 - leftCompactPanePositionRadioButton_Checked(sender, e)

        /// <summary>
        /// 왼쪽 컴팩트 창 위치 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void leftCompactPanePositionRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            this.navigationView.PaneDisplayMode = Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode.LeftCompact;
            this.navigationView.IsPaneOpen      = false;
        }

        #endregion
    }
}